<?php

namespace Litecms\ClientLogo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ClientLogo\Models\ClientLogo;

class ClientLogoPolicy
{

    /**
     * Determine if the given user can view the client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function view(UserPolicy $user, ClientLogo $client_logo)
    {
        if ($user->canDo('client_logo.client_logo.view') && $user->isAdmin()) {
            return true;
        }

        return $client_logo->user_id == user_id() && $client_logo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('client_logo.client_logo.create');
    }

    /**
     * Determine if the given user can update the given client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function update(UserPolicy $user, ClientLogo $client_logo)
    {
        if ($user->canDo('client_logo.client_logo.edit') && $user->isAdmin()) {
            return true;
        }

        return $client_logo->user_id == user_id() && $client_logo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ClientLogo $client_logo)
    {
        return $client_logo->user_id == user_id() && $client_logo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ClientLogo $client_logo)
    {
        if ($user->canDo('client_logo.client_logo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given client_logo.
     *
     * @param UserPolicy $user
     * @param ClientLogo $client_logo
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ClientLogo $client_logo)
    {
        if ($user->canDo('client_logo.client_logo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
