<?php

namespace Litecms\ClientLogo\Providers;

use Illuminate\Support\ServiceProvider;

class ClientLogoServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'client_logo');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'client_logo');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerClientLogo();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerClientLogo()
    {
        $this->app->bind('client_logo', function($app) {
            return new ClientLogo($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('ClientLogo', 'Lavalite\ClientLogo\Facades\ClientLogo');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.client_logo', function ($app) {
            return $this->app->make('Litecms\ClientLogo\ClientLogo');
        });

                // Bind ClientLogo to repository
        $this->app->bind(
            'Litecms\ClientLogo\Interfaces\ClientLogoRepositoryInterface',
            \Litecms\ClientLogo\Repositories\Eloquent\ClientLogoRepository::class
        );

        $this->app->register(\Litecms\ClientLogo\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\ClientLogo\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and client_logo's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/client_logo.php', 'client_logo'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeClientLogo::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.client_logo'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/client_logo.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/client_logo')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/client_logo')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
